package com.sky.controller.user;

import com.alibaba.fastjson.JSON;
import com.sky.common.constant.StatusConstant;
import com.sky.common.result.Result;
import com.sky.pojo.entity.Dish;
import com.sky.pojo.vo.DishVO;
import com.sky.service.DishService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.concurrent.TimeUnit;

@RestController("userDishController")
@RequiredArgsConstructor
@RequestMapping("/user/dish")
@Slf4j
@Api(tags = "C端-菜品浏览接口")
public class DishController {
    private final RedisTemplate<Object, Object> redisTemplate;
    DishService dishService;

    @GetMapping("/list")
    @ApiOperation("根据分类id查询菜品")
    public Result<List<DishVO>> list(Long categoryId) {
        // 构造redis中的key，规则dish_分类id
        String key = "dish_" + categoryId;
        // 查询redis中是否存在菜品数据
        List<DishVO> list = (List<DishVO>) redisTemplate.opsForValue().get(key);
        // 如果存在返回，无需查询数据库
        if (list != null && !list.isEmpty()) {
            return Result.success(list);
        }
        // 如果不存在查询数据库，将查询数据放入redis中
        Dish dish = new Dish();
        dish.setCategoryId(categoryId);
        dish.setStatus(StatusConstant.ENABLE);// 查询起售中的菜品

        list = dishService.listWithFlavor(dish);
        redisTemplate.opsForValue().set(key, JSON.toJSON(list), 7, TimeUnit.DAYS);
        return Result.success(list);
    }
}
