package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.pojo.dto.GoodsSalesDTO;
import com.sky.pojo.dto.OrdersPageQueryDTO;
import com.sky.pojo.entity.Orders;
import org.apache.ibatis.annotations.Mapper;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

@Mapper
public interface OrderMapper {
    /**
     * 插入订单数据
     *
     * @param order order
     */
    void insert(Orders order);

    /**
     * 根据订单号查询订单
     *
     * @param orderNumber orderNumber
     */
    Orders getByNumber(String orderNumber);

    /**
     * 修改订单信息
     *
     * @param orders orders
     */
    void update(Orders orders);

    /**
     * 根据动态条件统计营业额
     *
     * @param map map
     * @return Double
     */
    Double sumByMap(Map map);

    /**
     * 根据动态条件查询订单总数
     *
     * @param map 动态条件
     * @return 数字
     */
    Integer countByMap(Map map);

    /**
     * 查询销量前10
     *
     * @param begin 开始时间
     * @param end   结束时间
     * @return 查询销量前10列表
     */
    List<GoodsSalesDTO> getSalesTop10(LocalDateTime begin, LocalDateTime end);

    /**
     * 分页条件查询
     *
     * @param ordersPageQueryDTO 订单请求数据
     * @return 订单信息
     */
    Page<Orders> pageQuery(OrdersPageQueryDTO ordersPageQueryDTO);

    /**
     * 定时处理超时订单
     *
     * @param status    状态
     * @param orderTime 订单时间
     * @return 订单列表
     */
    List<Orders> getByStatusAndOrderTime(Integer status, LocalDateTime orderTime);

    /**
     * 根据id查询订单
     *
     * @param id 订单id
     * @return 订单数据
     */
    Orders getById(Long id);

    /**
     * 根据状态统计订单数量
     *
     * @param status 订单状态
     */
    Integer countStatus(Integer status);
}
