package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.annotation.AutoFill;
import com.sky.common.enumeration.OperationType;
import com.sky.pojo.dto.SetmealPageQueryDTO;
import com.sky.pojo.entity.Setmeal;
import com.sky.pojo.vo.DishItemVO;
import com.sky.pojo.vo.SetmealVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

@Mapper
public interface SetmealMapper {

    /**
     * 根据分类id查询套餐的数量
     *
     * @param id 当前id
     * @return 数量
     */
    Integer countByCategoryId(Long id);

    /**
     * 根据id修改套餐
     *
     * @param setmeal 套餐
     */
    @AutoFill(OperationType.UPDATE)
    void update(Setmeal setmeal);

    /**
     * 分页查询
     *
     * @param dto 前端请求
     * @return Page结果
     */
    Page<SetmealVO> pageQuery(SetmealPageQueryDTO dto);

    /**
     * 查找套餐
     *
     * @param id 套餐id
     * @return 套餐
     */
    Setmeal getById(Long id);

    /**
     * 插入套餐
     *
     * @param setmeal 套餐信息
     */
    @AutoFill(OperationType.INSERT)
    void insert(Setmeal setmeal);

    /**
     * 批量删除套餐
     *
     * @param ids 要删除套餐ids
     */
    void delete(List<Long> ids);

    /**
     * 动态条件查询套餐
     *
     * @param setmeal 菜品
     * @return List<Setmeal>
     */
    List<Setmeal> list(Setmeal setmeal);

    /**
     * 根据套餐id查询菜品选项
     *
     * @param setmealId setmealId
     * @return List<DishItemVO>
     */
    List<DishItemVO> getDishItemBySetmealId(Long setmealId);

    /**
     * 根据条件统计套餐数量
     *
     * @param map map
     * @return 数量
     */
    Integer countByMap(Map map);
}
